<?php

namespace Drupal\prod_check_xmlrpc\Plugin\ProdCheckProcessor;

use Drupal\Core\Form\FormStateInterface;
use Drupal\prod_check\Plugin\ProdCheckProcessor\ConfigurableProdCheckProcessorBase;
use Drupal\prod_check\Entity\ProdCheck as ProdCheckEntity;

/**
 * XML-RPC processor
 *
 * @ProdCheckProcessor(
 *   id = "xmlrpc",
 *   title = @Translation("XML-RPC processor"),
 * )
 */
class XmlRpc extends ConfigurableProdCheckProcessorBase {

  /**
   * Fetches all plugins in a format prod monitor can deal with.
   */
  public function listPlugins() {
    $plugins = $this->categoryManager->getDefinitions();

    $query = $this->queryService->get('prod_check')
      ->condition('status', 1);
    $checks = $query->execute();

    foreach ($checks as $check) {
      $plugin = $check->getPlugin();
      if (isset($plugins[$plugin['category']])) {
        $plugins[(string) $plugin['category']]['functions'][$plugin['id']] = (string) $plugin['title'];
      }
    }

    return $plugins;
  }

  /**
   * Helper function to check for correct API key.
   */
  function verifyKey($ping_key) {
    $connect_key = $this->configuration['key'];

    $result = FALSE;
    if ($connect_key && $ping_key == $connect_key) {
      $result = TRUE;
    }

    return $result;
  }

  /**
   * Processes a single prod check plugin
   */
  public function process($plugin_id) {
    $entity = ProdCheckEntity::load($plugin_id);
    if ($entity) {
      $check = $entity->getPlugin();
      $check->setProcessor($this);

      $check = $this->checkManager->createInstance($plugin_id, array('processor' => $this));

      $status = $check->state();
      $requirement = array(
        'status' => $status,
        'severity' => $status ? $this->ok() : $check->severity(),
        'title' => (string) $check->title(),
      );

      if ($status) {
        $requirement += $check->successMessages();
      }
      else {
        $requirement += $check->failMessages();
      }

      return $requirement;
    }
    else {
      return FALSE;
    }
  }

  /**
   * {@inheritdoc}
   */
  public function defaultConfiguration() {
    return array(
      'key' => '',
    );
  }

  /**
   * {@inheritdoc}
   */
  public function buildConfigurationForm(array $form, FormStateInterface $form_state) {
    $form['key'] = array(
      '#type' => 'textfield',
      '#title' => t('API key'),
      '#default_value' => $this->configuration['key'],
      '#required' => TRUE,
    );
    return $form;
  }

  /**
   * {@inheritdoc}
   */
  public function submitConfigurationForm(array &$form, FormStateInterface $form_state) {
    $this->configuration['key'] = $form_state->getValue('key');
  }

}
