<?php

namespace Drupal\prod_check\Controller;

use Drupal\Core\Controller\ControllerBase;
use Drupal\Core\DependencyInjection\ContainerInjectionInterface;
use Drupal\prod_check\Entity\ProdCheckProcessor;
use Drupal\prod_check\Plugin\ProdCheckProcessorPluginManager;
use Symfony\Component\DependencyInjection\ContainerInterface;

/**
 * Route controller fields.
 */
class StatusReportController extends ControllerBase implements ContainerInjectionInterface {

  /**
   * The prod check processor plugin manager.
   *
   * @var \Drupal\prod_check\Plugin\ProdCheckProcessorPluginManager;
   */
  protected $processManager;

  /**
   * Constructs a \Drupal\prod_check\Controller\StatusReportController object.
   *
   * @param \Drupal\prod_check\Plugin\ProdCheckProcessorPluginManager $manager
   *   The prod check processor plugin manager.
   */
  public function __construct(ProdCheckProcessorPluginManager $process_manager) {
    $this->processManager = $process_manager;
  }

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container) {
    return new static(
      $container->get('plugin.manager.prod_check_processor')
    );
  }

  /**
   * Builds a list of fields
   */
  public function build() {
    /** @var ProdCheckProcessor $internal_processor */
    $internal_processor = ProdCheckProcessor::load('internal');
    $requirements = $internal_processor->getPlugin()->requirements();

    return array(
      '#theme' => 'prod_check_status_report',
      '#requirements' => $requirements
    );
  }

}
